@@ -1,4 +1,6 @@
 import logging
+import os
+from typing import List
 
 from tavern._core.loader import load_single_document_yaml
 
@@ -7,19 +9,19 @@ from .dict_util import deep_dict_merge
 logger = logging.getLogger(__name__)
 
 
-def load_global_config(global_cfg_paths):
+def load_global_config(global_cfg_paths: List[os.PathLike]) -> dict:
     """Given a list of file paths to global config files, load each of them and
     return the joined dictionary.
 
     This does a deep dict merge.
 
     Args:
-        global_cfg_paths (list(str)): List of filenames to load from
+        global_cfg_paths: List of filenames to load from
 
     Returns:
-        dict: joined global configs
+        joined global configs
     """
-    global_cfg = {}
+    global_cfg: dict = {}
 
     if global_cfg_paths:
         logger.debug("Loading global config from %s", global_cfg_paths)
